package com.xxl.job.admin.core.scheduler;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import com.xxl.job.admin.core.conf.XxlJobAdminConfig;
import com.xxl.job.admin.core.thread.JobCompleteHelper;
import com.xxl.job.admin.core.thread.JobFailMonitorHelper;
import com.xxl.job.admin.core.thread.JobLogReportHelper;
import com.xxl.job.admin.core.thread.JobRegistryHelper;
import com.xxl.job.admin.core.thread.JobScheduleHelper;
import com.xxl.job.admin.core.thread.JobTriggerPoolHelper;
import com.xxl.job.admin.core.util.I18nUtil;
import com.xxl.job.core.biz.ExecutorBiz;
import com.xxl.job.core.biz.client.ExecutorBizClient;
import com.xxl.job.core.enums.ExecutorBlockStrategyEnum;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class XxlJobScheduler {
  private static final Logger logger = LoggerFactory.getLogger(com.xxl.job.admin.core.scheduler.XxlJobScheduler.class);
  
  public void init() throws Exception {
    initI18n();
    JobTriggerPoolHelper.toStart();
    JobRegistryHelper.getInstance().start();
    JobFailMonitorHelper.getInstance().start();
    JobCompleteHelper.getInstance().start();
    JobLogReportHelper.getInstance().start();
    JobScheduleHelper.getInstance().start();
    logger.info(">>>>>>>>> init xxl-job admin success.");
  }
  
  public void destroy() throws Exception {
    JobScheduleHelper.getInstance().toStop();
    JobLogReportHelper.getInstance().toStop();
    JobCompleteHelper.getInstance().toStop();
    JobFailMonitorHelper.getInstance().toStop();
    JobRegistryHelper.getInstance().toStop();
    JobTriggerPoolHelper.toStop();
  }
  
  private void initI18n() {
    for (ExecutorBlockStrategyEnum item : ExecutorBlockStrategyEnum.values())
      item.setTitle(I18nUtil.getString("jobconf_block_".concat(item.name()))); 
  }
  
  private static ConcurrentMap<String, ExecutorBiz> executorBizRepository = new ConcurrentHashMap<>();
  
  public static ExecutorBiz getExecutorBiz(String address) throws Exception {
    if (address == null || address.trim().length() == 0)
      return null; 
    address = address.trim();
    ExecutorBiz executorBiz = executorBizRepository.get(address);
    if (executorBiz != null)
      return executorBiz; 
    ExecutorBizClient executorBizClient = new ExecutorBizClient(address, XxlJobAdminConfig.getAdminConfig().getAccessToken(), XxlJobAdminConfig.getAdminConfig().getTimeout());
    executorBizRepository.put(address, executorBizClient);
    return (ExecutorBiz)executorBizClient;
  }
}
